@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.57 2002/06/05 03:08:06 jirka Exp $ */
+/* $Id: gdict-app.c,v 1.57.2.2 2002/09/19 17:23:21 gman Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -200,6 +200,20 @@ void
 gdict_app_do_lookup (gchar *text) 
 {
     gint retval;
+    gchar *word_entry_text;
+    
+    g_return_if_fail (text != NULL);
+    
+    /* If needed update the the word_entry */
+    word_entry_text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
+    if ((word_entry_text == NULL) || (*word_entry_text == 0) || (strcmp (word_entry_text, text) != 0))
+    {
+        g_strdown (text);
+        gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
+        gtk_entry_set_text (GTK_ENTRY (word_entry), text);
+    }
+
+    g_free (word_entry_text);
 
     if (gdict_pref.smart && is_pattern (text)) {
 	retval = gdict_spell (text, TRUE);
@@ -233,7 +247,7 @@ lookup_defbox (void)
     gtk_signal_emit_by_name (GTK_OBJECT (word_entry), "paste_clipboard");
     text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
     g_strdown (text);
-    gnome_entry_append_history (GNOME_ENTRY (gnome_word_entry), 1, text);
+    gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
     gdict_app_do_lookup (text);
     if (text)
         g_free (text);
@@ -311,7 +325,7 @@ lookup_button_drag_cb (GtkWidget *widget, GdkDragContext *context, gint x, gint
 	if (text) {
 		g_strdown (text);
 		gtk_entry_set_text (GTK_ENTRY (word_entry), text);
-    		gnome_entry_append_history (GNOME_ENTRY (gnome_word_entry), 1, text);
+    		gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
     		gdict_app_do_lookup (text);
 		g_free (text);
 	}
@@ -806,6 +820,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
     		      G_CALLBACK (lookup_button_drag_cb), defbox);
 
     gnome_word_entry = gnome_entry_new ("Wordentry");
+    gnome_entry_set_max_saved (GNOME_ENTRY (gnome_word_entry), 10);
     gtk_widget_show (gnome_word_entry);
     gtk_box_pack_start (GTK_BOX (hbox), gnome_word_entry, TRUE, TRUE, 0);
     gnome_entry_set_max_saved (GNOME_ENTRY (gnome_word_entry), 50);
