@@ -38,17 +38,11 @@ extern int errno;
 static GFloppy floppy;
 static GladeXML *xml;
 static GtkWidget *toplevel = NULL;
+static GtkWidget *type_option;
 
 /* Only needed if more then one device exists */
 static GList *valid_devices = NULL;
 
-enum
-{
-  GFLOPPY_FORMAT,
-  GFLOPPY_CLOSE,
-  GFLOPPY_HELP
-};
-
 static void
 devices_option_activated (GtkWidget *menu_item, gchar *device)
 {
@@ -93,11 +87,22 @@ start_format (void)
 static void
 init_commands (void)
 {
+	const char *path;
+	char *newpath;
+
 	floppy.mke2fs_cmd = NULL;
 	floppy.mformat_cmd = NULL;
 	floppy.badblocks_cmd = NULL;
 
-	putenv ("PATH=$PATH:/sbin:/usr/sbin:/usr:/usr/bin");
+	path = g_getenv ("PATH");
+
+	if (path)
+		newpath = g_strconcat ("PATH=", path, ":/sbin:/usr/sbin:/usr:/usr/bin", NULL);
+	else
+		newpath = g_strdup ("PATH=/sbin:/usr/sbin:/usr:/usr/bin");
+
+	putenv (newpath); /* Sigh, we have to leak it */
+
 	floppy.mke2fs_cmd    = g_find_program_in_path ("mke2fs");
 	floppy.mformat_cmd   = g_find_program_in_path ("mformat");
 	floppy.badblocks_cmd = g_find_program_in_path ("mbadblocks");
@@ -260,22 +265,89 @@ set_floppy_extended_device (void)
 }
 
 gint
-on_toplevel_delete_event (GtkWidget *w, GdkEventAny *e, gpointer data)
+on_toplevel_delete_event (GtkWidget *w, GdkEventKey *e)
 {
-	toplevel = NULL;
+	gtk_main_quit ();
 	return TRUE;
 }
 
+void
+on_close_button_clicked (GtkWidget *widget, gpointer user_data)
+{
+	gtk_main_quit ();
+}
+
+void
+on_help_button_clicked (GtkWidget *widget, gpointer user_data)
+{
+	GError *error = NULL;
+
+	gnome_help_display ("gfloppy", "intro", &error);
+	if (error) {
+		GtkWidget *dialog;
+
+		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel), GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+						 _("Could not display help for the "
+						   "floppy formatter.\n"
+						   "%s"),
+						 error->message);
+
+		g_signal_connect (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy), NULL);
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		gtk_widget_show (dialog);
+
+		g_error_free (error);
+	}
+}
+
+void
+on_format_button_clicked (GtkWidget *widget, gpointer user_data)
+{
+	GtkWidget *dialog;
+	GtkWidget *density_option;
+	GtkWidget *quick_format_button;
+
+        density_option = glade_xml_get_widget (xml, "density_option");
+	quick_format_button = glade_xml_get_widget (xml, "quick_format_button");
+
+        g_assert (density_option != NULL);
+        g_assert (quick_format_button != NULL);
+
+        gtk_widget_set_sensitive (toplevel, FALSE);
+
+        if (floppy.mformat_cmd) {
+        	/* Check to see which one is selected. */
+                floppy.type = gtk_option_menu_get_history (GTK_OPTION_MENU (type_option));
+        } else {
+                floppy.type = GFLOPPY_E2FS;
+        }
+        floppy.size = gtk_option_menu_get_history (GTK_OPTION_MENU (density_option));
+        set_floppy_extended_device ();
+        floppy.quick_format = GTK_TOGGLE_BUTTON (quick_format_button)->active;
+
+        start_format ();
+        if (!toplevel)
+        	return;
+        gtk_widget_set_sensitive (toplevel, TRUE); /*
+        dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
+                                         GTK_DIALOG_MODAL,
+                                         GTK_MESSAGE_QUESTION,
+                                         GTK_BUTTONS_YES_NO,
+                                         _("Format another floppy?"));
+        if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_YES)
+        	exit (0);
+        gtk_widget_destroy (dialog); */
+}
+
 int
 main (int argc, char *argv[])
 {
 	GtkWidget *ext2_entry;
-	GtkWidget *type_option;
 	GtkWidget *icon_frame;
 	GtkWidget *icon;
-	GtkWidget *quick_format_button;
-	GtkWidget *device_combo;
-	gint button;
+	gchar *image;
 
 	struct poptOption gfloppy_opts[] = {
 		{"device", '\0', POPT_ARG_STRING, NULL, 0, NULL, NULL},
@@ -291,28 +363,32 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gnome_init_with_popt_table ("gfloppy", VERSION, argc, argv,
-				    gfloppy_opts, 0, NULL);
+	gnome_program_init ("gfloppy",VERSION, LIBGNOMEUI_MODULE,
+			    argc, argv, GNOME_PARAM_POPT_TABLE, gfloppy_opts,
+                            GNOME_PARAM_POPT_FLAGS, 0,
+                            GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
 	/* FIXME: get the right icon */
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/mc/i-floppy.png");
+	image = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
+                                           "document-icons/i-floppy.png", TRUE, NULL);
+
+	
+	gnome_window_icon_set_default_from_file (image);
+	g_free (image);
+
 	init_commands ();
 
 	/* Now we can set up glade */
 	glade_gnome_init();
-//        xml = glade_xml_new (GLADEDIR "/gfloppy2.glade", NULL, NULL);
-//	if (xml == NULL)
-		xml = glade_xml_new ("gfloppy2.glade", NULL, NULL);
+        xml = glade_xml_new (GLADEDIR "/gfloppy2.glade", NULL, NULL);
 	if (xml == NULL)
-		g_error ("Cannot load/find floppy.glade");
+		g_error ("Cannot load/find gfloppy2.glade");
 
 	init_devices ();
 	toplevel = glade_xml_get_widget (xml, "toplevel");
 
-	quick_format_button = glade_xml_get_widget (xml, "quick_format_button");
 	icon_frame = glade_xml_get_widget (xml, "icon_frame");
 	type_option = glade_xml_get_widget (xml, "type_option");
 	toplevel = glade_xml_get_widget (xml, "toplevel");
-	device_combo = glade_xml_get_widget (xml, "device_combo");
 	glade_xml_signal_autoconnect (xml);
 	
 	icon = gtk_image_new_from_stock (GTK_STOCK_FLOPPY, GTK_ICON_SIZE_DIALOG);
@@ -327,49 +403,9 @@ main (int argc, char *argv[])
 		gtk_widget_show (ext2_entry);
 	}
 
-	while ((button = gtk_dialog_run (GTK_DIALOG (toplevel))) >= 0) {
-		GtkWidget *density_option;
-		GtkWidget *dialog;
+	gtk_widget_show (GTK_WIDGET (toplevel));
+	gtk_main ();
 
-		if (button == GFLOPPY_CLOSE) 
-			break;
-
-		if (button == GFLOPPY_HELP) {
-#if 0
-			GnomeHelpMenuEntry ref = {"gfloppy", "index.html"};
-			gnome_help_display (NULL, &ref);
-#endif
-			continue;
-		}
-		density_option = glade_xml_get_widget (xml, "density_option");
-		g_assert (density_option != NULL);
-		g_assert (quick_format_button != NULL);
-
-		gtk_widget_set_sensitive (toplevel, FALSE);
-
-		if (floppy.mformat_cmd) {
-			/* Check to see which one is selected. */
-			floppy.type = gtk_option_menu_get_history (GTK_OPTION_MENU (type_option));
-		} else {
-			floppy.type = GFLOPPY_E2FS;
-		}
-		floppy.size = gtk_option_menu_get_history (GTK_OPTION_MENU (density_option));
-		set_floppy_extended_device ();
-		floppy.quick_format = GTK_TOGGLE_BUTTON (quick_format_button)->active;
-
-		start_format ();
-		if (!toplevel)
-			break;
-		gtk_widget_set_sensitive (toplevel, TRUE);
-		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_QUESTION,
-						 GTK_BUTTONS_YES_NO,
-						 _("Format another floppy?"));
-		if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_YES)
-			exit (0);
-		gtk_widget_destroy (dialog);
-	}
 	return 0;
 }
 
