@@ -29,6 +29,7 @@ static gchar *tarstr = NULL;
 static gchar *filestr = NULL;
 static gchar *gzipstr = NULL;
 static gchar *filename = NULL;
+static gchar *archivename = NULL;
 static pid_t temporary_pid = 0;
 static gchar *temporary_file = NULL;
 struct poptOption options;
@@ -232,10 +233,9 @@ start_progress_bar (gboolean flag)
 static void
 setup_busy (GtkWidget *w, gboolean busy)
 {
-	GdkCursor *cursor;
-	static gint timeout;
 
 	if (busy) {
+		GdkCursor *cursor;
 		/* Change cursor to busy */
 		cursor = gdk_cursor_new (GDK_WATCH);
 		gdk_window_set_cursor (w->window, cursor);
@@ -255,6 +255,7 @@ handle_io (GIOChannel *ioc, GIOCondition condition, gpointer data)
 	g_hash_table_foreach (file_ht, whack_links_fe, argv_adder.link_dir);
 
 	/* FIXME: handle errors */
+	g_io_channel_close(ioc);
 	rmdir (argv_adder.link_dir);
 	g_free (argv_adder.link_dir);
 	g_free (argv_adder.argv);
@@ -500,7 +501,8 @@ about_cb (GtkWidget *widget, gpointer data)
 	if (pixbuf) {
 		gdk_pixbuf_unref (pixbuf);
 	}			 
-	
+
+	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (data));	
 	g_signal_connect (G_OBJECT (about), "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
 			  &about);
@@ -632,8 +634,8 @@ save_ok (GtkWidget *widget, GtkFileSelection *fsel)
 	}
 
         status_msg = g_strdup_printf(_("%s created"), g_path_get_basename(fname));
-	g_free (filename);
-	filename = g_strdup (fname);
+	g_free (archivename);
+	archivename = g_strdup (fname);
         gnome_appbar_push (GNOME_APPBAR (app_bar), 
                            status_msg);
        g_free (status_msg);
@@ -650,8 +652,12 @@ archive_cb (GtkWidget *w, gpointer data)
 	}
 
 	fsel = GTK_FILE_SELECTION(gtk_file_selection_new(_("Save Results")));
-	if (filename != NULL)
-		gtk_file_selection_set_filename (fsel, filename);
+	if (archivename != NULL)
+		gtk_file_selection_set_filename (fsel, archivename);
+	else {
+		gtk_file_selection_set_filename (fsel, "untitled.tar.gz");
+		gtk_editable_select_region (GTK_EDITABLE (fsel->selection_entry), 0, -1);
+	}
 
 	g_signal_connect (G_OBJECT (fsel->ok_button), "clicked",
 			  G_CALLBACK (save_ok), fsel);
@@ -943,7 +949,7 @@ static GnomeUIInfo edit_menu[] = {
 };
 
 static GnomeUIInfo help_menu[] = {
-	GNOMEUIINFO_HELP ("meat-grinder"),
+	GNOMEUIINFO_HELP ("archive-generator"),
 	GNOMEUIINFO_MENU_ABOUT_ITEM (about_cb, NULL),
 	GNOMEUIINFO_END
 };
@@ -976,7 +982,7 @@ init_gui (void)
 
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/document-icons/gnome-compressed.png");
         
-	gnome_app_create_menus (GNOME_APP (app), grinder_menu);
+	gnome_app_create_menus_with_data (GNOME_APP (app), grinder_menu, app);
 
         g_signal_connect (G_OBJECT (app), "delete_event",
 			  G_CALLBACK (quit_cb), NULL);
@@ -1127,9 +1133,9 @@ main (gint argc, gchar *argv [])
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gnome_program_init ("meat-grinder", VERSION, LIBGNOMEUI_MODULE,
-				    argc, argv, GNOME_PARAM_POPT_TABLE,
-				    &options,GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
+	gnome_program_init ("archive-generator", VERSION, LIBGNOMEUI_MODULE,
+			    argc, argv, GNOME_PARAM_POPT_TABLE,
+			    &options,GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
 
 	client = gnome_master_client ();
 
